@@ -20,6 +20,8 @@
 
 #include "address.h"
 #include "geo.h"
+#include "countrytoisomap_data.cpp"
+#include "isotocountrymap_data.cpp"
 
 #include "kcontacts_debug.h"
 #include <krandom.h>
@@ -586,6 +588,12 @@ static QString countryCodeFromLocale()
     return {};
 }
 
+static QString addressFormatRc()
+{
+    Q_INIT_RESOURCE(kcontacts); // must be called outside of a namespace
+    return QStringLiteral(":/org.kde.kcontacts/addressformatrc");
+}
+
 QString Address::formattedAddress(const QString &realName, const QString &orgaName) const
 {
     QString ciso;
@@ -599,7 +607,7 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
         // fall back to our own country
         ciso = countryCodeFromLocale();
     }
-    static KConfig entry(QStringLiteral(":/org.kde.kcontacts/addressformatrc"));
+    static const KConfig entry(addressFormatRc());
 
     KConfigGroup group = entry.group(ciso);
     // decide whether this needs special business address formatting
@@ -643,38 +651,27 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
     return ret;
 }
 
-struct IsoCache {
-    QHash<QString, QString> countryToIso;
-    QHash<QString, QString> isoToCountry;
-};
-Q_GLOBAL_STATIC(IsoCache, sIsoCache)
-
 QString Address::countryToISO(const QString &cname)
 {
-    // we search a map file for translations from country names to
-    // iso codes, storing caching things in a QHash for faster future
-    // access.
+    const auto lookupKey = cname.toCaseFolded().toUtf8();
 
-    const auto it = sIsoCache->countryToIso.constFind(cname);
-    if (it != sIsoCache->countryToIso.constEnd()) {
-        return it.value();
+    // look for an exact match
+    auto it = std::lower_bound(std::begin(country_to_iso_index), std::end(country_to_iso_index), lookupKey, [](const CountryToIsoIndex &lhs, const QByteArray &rhs) {
+        return strcmp(country_name_stringtable + lhs.m_offset, rhs.constData()) < 0;
+    });
+    if (it != std::end(country_to_iso_index) && strcmp(country_name_stringtable + (*it).m_offset, lookupKey.constData()) == 0) {
+        return (*it).isoCode();
     }
 
-    QFile file(QStringLiteral(":/org.kde.kcontacts/countrytransl.map"));
-    if (file.open(QIODevice::ReadOnly)) {
-        QTextStream s(&file);
-        QString strbuf = s.readLine();
-        while (!strbuf.isEmpty()) {
-            const auto countryInfo = strbuf.splitRef(QLatin1Char('\t'), QString::KeepEmptyParts);
-            if (countryInfo[0] == cname) {
-                file.close();
-                const auto iso = countryInfo[1].toString();
-                sIsoCache->countryToIso.insert(cname, iso);
-                return iso;
-            }
-            strbuf = s.readLine();
-        }
-        file.close();
+    // a unique prefix will do too
+    it = std::lower_bound(std::begin(country_to_iso_index), std::end(country_to_iso_index), lookupKey, [](const CountryToIsoIndex &lhs, const QByteArray &rhs) {
+        return strncmp(country_name_stringtable + lhs.m_offset, rhs.constData(), strlen(country_name_stringtable + lhs.m_offset)) < 0;
+    });
+    const auto endIt = std::upper_bound(std::begin(country_to_iso_index), std::end(country_to_iso_index), lookupKey, [](const QByteArray &lhs, const CountryToIsoIndex &rhs) {
+        return strncmp(lhs.constData(), country_name_stringtable + rhs.m_offset, strlen(country_name_stringtable + rhs.m_offset)) < 0;
+    });
+    if (it != std::end(country_to_iso_index) && endIt == (it + 1) && strncmp(country_name_stringtable + (*it).m_offset, lookupKey.constData(), strlen(country_name_stringtable + (*it).m_offset)) == 0) {
+        return (*it).isoCode();
     }
 
     return {};
@@ -683,33 +680,16 @@ QString Address::countryToISO(const QString &cname)
 QString Address::ISOtoCountry(const QString &ISOname)
 {
     // get country name from ISO country code (e.g. "no" -> i18n("Norway"))
-    const auto iso = ISOname.simplified().toLower();
-    if (iso.simplified().isEmpty()) {
-        return QString();
+    const auto iso = ISOname.simplified().toLower().toUtf8();
+    if (iso.size() != 2) {
+        return ISOname;
     }
 
-    const auto it = sIsoCache->isoToCountry.constFind(iso);
-    if (it != sIsoCache->isoToCountry.constEnd()) {
-        return it.value();
-    }
-
-    QFile file(QStringLiteral(":/org.kde.kcontacts/countrytransl.map"));
-    if (file.open(QIODevice::ReadOnly)) {
-        QTextStream s(&file);
-        QString searchStr = QLatin1Char('\t') + iso;
-        QString strbuf = s.readLine();
-        while (!strbuf.isEmpty()) {
-            int pos;
-            if ((pos = strbuf.indexOf(searchStr)) != -1) {
-                file.close();
-                const auto country = i18n(strbuf.leftRef(pos).toUtf8().constData());
-                sIsoCache->isoToCountry.insert(iso, country);
-                sIsoCache->countryToIso.insert(country, iso);
-                return country;
-            }
-            strbuf = s.readLine();
-        }
-        file.close();
+    const auto it = std::lower_bound(std::begin(iso_to_country_index), std::end(iso_to_country_index), iso.constData(), [](const IsoToCountryIndex &lhs, const char *rhs) {
+        return strncmp(&lhs.m_c1, rhs, 2) < 0;
+    });
+    if (it != std::end(iso_to_country_index) && strncmp(&(*it).m_c1, iso.constData(), 2) == 0) {
+        return i18nd("iso_3166-1", en_country_name_stringtable + (*it).m_offset);
     }
 
     return ISOname;
